@@ -1,24 +1,12 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 /*
  * Copyright (C) 2015 Red Hat, Inc.
  *
  * This file is part of the device-mapper multipath userspace tools.
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIB_MPATH_CMD_H
-#define LIB_MPATH_CMD_H
+#ifndef MPATH_CMD_H_INCLUDED
+#define MPATH_CMD_H_INCLUDED
 
 /*
  * This should be sufficient for json output for >10000 maps,
@@ -30,7 +18,6 @@
 extern "C" {
 #endif
 
-#define DEFAULT_SOCKET		"/org/kernel/linux/storage/multipathd"
 #define DEFAULT_REPLY_TIMEOUT	4000
 
 
@@ -47,7 +34,7 @@ extern "C" {
  * RETURNS:
  *	A file descriptor on success. -1 on failure (with errno set).
  */
-int __mpath_connect(int nonblocking);
+int mpath_connect__(int nonblocking);
 
 /*
  * DESCRIPTION:
@@ -65,7 +52,7 @@ int mpath_connect(void);
 /*
  * DESCRIPTION:
  *	Disconnect from the multipathd daemon. This function must be
- *	run after after processing all the multipath commands.
+ *	run after processing all the multipath commands.
  *
  * RETURNS:
  *	0 on success. -1 on failure (with errno set).
@@ -80,7 +67,7 @@ int mpath_disconnect(int fd);
  *	mpath_recv_reply()
  *
  * RETURNS:
- *	0 on successs, and reply will either be NULL (if there was no
+ *	0 on success, and reply will either be NULL (if there was no
  *	reply data), or point to the reply string, which must be freed by
  *	the caller. -1 on failure (with errno set).
  */
@@ -141,4 +128,4 @@ int mpath_recv_reply_data(int fd, char *reply, size_t len,
 #ifdef __cplusplus
 }
 #endif
-#endif /* LIB_MPATH_CMD_H */
+#endif /* MPATH_CMD_H_INCLUDED */
