@@ -6,24 +6,16 @@
 #include "checkers.h"
 #include "libsg.h"
 
-#define MSG_READSECTOR0_UP	"readsector0 checker reports path is up"
-#define MSG_READSECTOR0_DOWN	"readsector0 checker reports path is down"
-
 struct readsector0_checker_context {
 	void * dummy;
 };
 
-int libcheck_init (struct checker * c)
+int libcheck_init (__attribute__((unused)) struct checker * c)
 {
 	return 0;
 }
 
-void libcheck_free (struct checker * c)
-{
-	return;
-}
-
-void libcheck_repair (struct checker * c)
+void libcheck_free (__attribute__((unused)) struct checker * c)
 {
 	return;
 }
@@ -40,10 +32,10 @@ int libcheck_check (struct checker * c)
 	switch (ret)
 	{
 	case PATH_DOWN:
-		MSG(c, MSG_READSECTOR0_DOWN);
+		c->msgid = CHECKER_MSGID_DOWN;
 		break;
 	case PATH_UP:
-		MSG(c, MSG_READSECTOR0_UP);
+		c->msgid = CHECKER_MSGID_UP;
 		break;
 	default:
 		break;
