@@ -1,8 +1,8 @@
-#ifndef _READSECTOR0_H
-#define _READSECTOR0_H
+#ifndef READSECTOR0_H_INCLUDED
+#define READSECTOR0_H_INCLUDED
 
 int readsector0 (struct checker *);
 int readsector0_init (struct checker *);
 void readsector0_free (struct checker *);
 
-#endif /* _READSECTOR0_H */
+#endif /* READSECTOR0_H_INCLUDED */
