@@ -1,8 +1,8 @@
-#ifndef _TUR_H
-#define _TUR_H
+#ifndef TUR_H_INCLUDED
+#define TUR_H_INCLUDED
 
 int tur (struct checker *);
 int tur_init (struct checker *);
 void tur_free (struct checker *);
 
-#endif /* _TUR_H */
+#endif /* TUR_H_INCLUDED */
