@@ -34,6 +34,7 @@
 #include "configure.h"
 #include "print.h"
 #include "strbuf.h"
+#include "pgpolicies.h"
 
 #define VPD_BUFLEN 4096
 
@@ -146,7 +147,7 @@ path_discover (vector pathvec, struct config * conf,
 		return pathinfo(pp, conf, flag);
 }
 
-static void cleanup_udev_enumerate_ptr(void *arg)
+void cleanup_udev_enumerate_ptr(void *arg)
 {
 	struct udev_enumerate *ue;
 
@@ -157,7 +158,7 @@ static void cleanup_udev_enumerate_ptr(void *arg)
 		(void)udev_enumerate_unref(ue);
 }
 
-static void cleanup_udev_device_ptr(void *arg)
+void cleanup_udev_device_ptr(void *arg)
 {
 	struct udev_device *ud;
 
@@ -875,7 +876,7 @@ sysfs_set_nexus_loss_tmo(struct path *pp)
 static void
 scsi_tmo_error_msg(struct path *pp)
 {
-	STATIC_BITFIELD(bf, LAST_BUS_PROTOCOL_ID + 1);
+	static BITFIELD(bf, LAST_BUS_PROTOCOL_ID + 1);
 	STRBUF_ON_STACK(proto_buf);
 	unsigned int proto_id = bus_protocol_id(pp);
 
@@ -1097,8 +1098,13 @@ detect_alua(struct path * pp)
 
 int path_get_tpgs(struct path *pp)
 {
-	if (pp->tpgs == TPGS_UNDEF)
+	if (pp->tpgs == TPGS_UNDEF) {
 		detect_alua(pp);
+		if (pp->tpgs != TPGS_UNDEF && pp->tpg_id != GROUP_ID_UNDEF &&
+		    pp->mpp &&
+		    pp->mpp->pgpolicyfn == (pgpolicyfn *)group_by_tpg)
+			pp->mpp->need_reload = true;
+	}
 	return pp->tpgs;
 }
 
@@ -1527,23 +1533,16 @@ scsi_sysfs_pathinfo (struct path *pp, const struct vector_s *hwtable)
 	const char *attr_path = NULL;
 	static const char unknown[] = "UNKNOWN";
 
-	parent = pp->udev;
-	while (parent) {
-		const char *subsys = udev_device_get_subsystem(parent);
-		if (subsys && !strncmp(subsys, "scsi", 4)) {
-			attr_path = udev_device_get_sysname(parent);
-			if (!attr_path)
-				break;
-			if (sscanf(attr_path, "%i:%i:%i:%" SCNu64,
-				   &pp->sg_id.host_no,
-				   &pp->sg_id.channel,
-				   &pp->sg_id.scsi_id,
-				   &pp->sg_id.lun) == 4)
-				break;
-		}
-		parent = udev_device_get_parent(parent);
-	}
-	if (!attr_path || pp->sg_id.host_no == -1)
+	parent = udev_device_get_parent_with_subsystem_devtype(pp->udev, "scsi",
+							       "scsi_device");
+	if (!parent)
+		return PATHINFO_FAILED;
+	attr_path = udev_device_get_sysname(parent);
+	if (!attr_path)
+		return PATHINFO_FAILED;
+	if (sscanf(attr_path, "%i:%i:%i:%" SCNu64,
+		   &pp->sg_id.host_no,
+		   &pp->sg_id.channel, &pp->sg_id.scsi_id, &pp->sg_id.lun) != 4)
 		return PATHINFO_FAILED;
 
 	if (sysfs_get_vendor(parent, pp->vendor_id, SCSI_VENDOR_SIZE) <= 0) {
@@ -1588,6 +1587,9 @@ scsi_sysfs_pathinfo (struct path *pp, const struct vector_s *hwtable)
 	condlog(3, "%s: tgt_node_name = %s",
 		pp->dev, pp->tgt_node_name);
 
+	if (get_vpd_sysfs(parent, 0x80, pp->serial, SERIAL_SIZE) > 0)
+		condlog(3, "%s: serial = %s (sysfs)", pp->dev, pp->serial);
+
 	return PATHINFO_OK;
 }
 
@@ -1667,6 +1669,7 @@ ccw_sysfs_pathinfo (struct path *pp, const struct vector_s *hwtable)
 	if (!parent)
 		return PATHINFO_FAILED;
 
+	// Identified as IBM, but any other PAV array vendor is also supported
 	sprintf(pp->vendor_id, "IBM");
 
 	condlog(3, "%s: vendor = %s", pp->dev, pp->vendor_id);
@@ -1912,15 +1915,10 @@ sysfs_pathinfo(struct path *pp, const struct vector_s *hwtable)
 }
 
 static void
-scsi_ioctl_pathinfo (struct path * pp, int mask)
+scsi_ioctl_pathinfo (struct path * pp)
 {
-	struct udev_device *parent;
-	const char *attr_path = NULL;
 	int vpd_id;
 
-	if (!(mask & DI_SERIAL))
-		return;
-
 	select_vpd_vendor_id(pp);
 	vpd_id = pp->vpd_vendor_id;
 
@@ -1940,34 +1938,13 @@ scsi_ioctl_pathinfo (struct path * pp, int mask)
 		}
 	}
 
-	parent = pp->udev;
-	while (parent) {
-		const char *subsys = udev_device_get_subsystem(parent);
-		if (subsys && !strncmp(subsys, "scsi", 4)) {
-			attr_path = udev_device_get_sysname(parent);
-			if (!attr_path)
-				break;
-			if (sscanf(attr_path, "%i:%i:%i:%" SCNu64,
-				   &pp->sg_id.host_no,
-				   &pp->sg_id.channel,
-				   &pp->sg_id.scsi_id,
-				   &pp->sg_id.lun) == 4)
-				break;
-		}
-		parent = udev_device_get_parent(parent);
-	}
-	if (!attr_path || pp->sg_id.host_no == -1)
-		return;
-
-	if (get_vpd_sysfs(parent, 0x80, pp->serial, SERIAL_SIZE) <= 0) {
-		if (get_serial(pp->serial, SERIAL_SIZE, pp->fd)) {
+	if (pp->serial[0] == '\0') {
+		if (get_serial(pp->serial, SERIAL_SIZE, pp->fd))
 			condlog(3, "%s: fail to get serial", pp->dev);
-			return;
-		}
+		else
+			condlog(3, "%s: serial = %s (ioctl)", pp->dev,
+				pp->serial);
 	}
-
-	condlog(3, "%s: serial = %s", pp->dev, pp->serial);
-	return;
 }
 
 static void
@@ -2269,7 +2246,7 @@ static ssize_t uid_fallback(struct path *pp, int path_state,
 	return len;
 }
 
-bool has_uid_fallback(struct path *pp)
+static bool has_uid_fallback(const struct path *pp)
 {
 	/*
 	 * Falling back to direct WWID determination is dangerous
@@ -2290,6 +2267,16 @@ bool has_uid_fallback(struct path *pp)
 		  !strcmp(pp->uid_attribute, ""))));
 }
 
+bool can_recheck_wwid(const struct path *pp)
+{
+	/*
+	 * check_path_wwid_change() only works for scsi devices, and it
+	 * is only guaranteed to give the same WWID if the path uses
+	 * the default uid_attribute
+	 */
+	return (pp->bus == SYSFS_BUS_SCSI && has_uid_fallback(pp));
+}
+
 int
 get_uid (struct path * pp, int path_state, struct udev_device *udev,
 	 int allow_fallback)
@@ -2347,6 +2334,7 @@ get_uid (struct path * pp, int path_state, struct udev_device *udev,
 int pathinfo(struct path *pp, struct config *conf, int mask)
 {
 	int path_state;
+	bool need_serial_recheck = false;
 
 	if (!pp || !conf)
 		return PATHINFO_FAILED;
@@ -2387,6 +2375,10 @@ int pathinfo(struct path *pp, struct config *conf, int mask)
 			   pp->dev) > 0)
 		return PATHINFO_SKIPPED;
 
+	if (pp->mpp && pp->mpp->pgpolicyfn == (pgpolicyfn *)group_by_serial &&
+	    pp->serial[0] == '\0')
+		need_serial_recheck = true;
+
 	condlog(4, "%s: mask = 0x%x", pp->dev, mask);
 
 	/*
@@ -2445,6 +2437,8 @@ int pathinfo(struct path *pp, struct config *conf, int mask)
 			    pp->state == PATH_UNCHECKED ||
 			    pp->state == PATH_WILD)
 				pp->chkrstate = pp->state = path_state;
+		if (need_serial_recheck && pp->serial[0] != '\0')
+			pp->mpp->need_reload = true;
 		return PATHINFO_OK;
 	}
 
@@ -2460,14 +2454,17 @@ int pathinfo(struct path *pp, struct config *conf, int mask)
 		goto blank;
 	}
 
-	if (mask & DI_SERIAL)
-		get_geometry(pp);
-
-	if (path_state == PATH_UP && pp->bus == SYSFS_BUS_SCSI)
-		scsi_ioctl_pathinfo(pp, mask);
-
-	if (pp->bus == SYSFS_BUS_CCISS && mask & DI_SERIAL)
-		cciss_ioctl_pathinfo(pp);
+	if (mask & DI_IOCTL || pp->ioctl_info == IOCTL_INFO_SKIPPED) {
+		if (path_state == PATH_UP) {
+			get_geometry(pp);
+			if (pp->bus == SYSFS_BUS_SCSI)
+				scsi_ioctl_pathinfo(pp);
+			else if (pp->bus == SYSFS_BUS_CCISS)
+				cciss_ioctl_pathinfo(pp);
+			pp->ioctl_info = IOCTL_INFO_COMPLETED;
+		} else if (pp->ioctl_info == IOCTL_INFO_NOT_REQUESTED)
+			pp->ioctl_info = IOCTL_INFO_SKIPPED;
+	}
 
 	if (mask & DI_CHECKER) {
 		if (path_state == PATH_UP) {
@@ -2551,6 +2548,8 @@ int pathinfo(struct path *pp, struct config *conf, int mask)
 
 	if ((mask & DI_ALL) == DI_ALL)
 		pp->initialized = INIT_OK;
+	if (need_serial_recheck && pp->serial[0] != '\0')
+		pp->mpp->need_reload = true;
 	return PATHINFO_OK;
 
 blank:
