@@ -2,8 +2,8 @@
  * Copyright (c) 2010 Benjamin Marzinski, Redhat
  */
 
-#ifndef _FILE_H
-#define _FILE_H
+#ifndef FILE_H_INCLUDED
+#define FILE_H_INCLUDED
 
 #include <sys/stat.h>
 
@@ -11,4 +11,4 @@
 int ensure_directories_exist(const char *str, mode_t dir_mode);
 int open_file(const char *file, int *can_write, const char *header);
 
-#endif /* _FILE_H */
+#endif /* FILE_H_INCLUDED */
