@@ -125,8 +125,7 @@ int prio_path_weight(struct path *pp, char *prio_args)
 	return priority;
 }
 
-int getprio(struct path *pp, char *args,
-	    __attribute__((unused)) unsigned int timeout)
+int getprio(struct path *pp, char *args)
 {
 	return prio_path_weight(pp, args);
 }
