@@ -1,5 +1,5 @@
-#ifndef _STRUCTS_VEC_H
-#define _STRUCTS_VEC_H
+#ifndef STRUCTS_VEC_H_INCLUDED
+#define STRUCTS_VEC_H_INCLUDED
 
 #include "vector.h"
 #include "config.h"
@@ -27,14 +27,16 @@ void remove_map (struct multipath *mpp, vector pathvec, vector mpvec);
 void remove_map_by_alias(const char *alias, struct vectors * vecs);
 void remove_maps (struct vectors * vecs);
 
-void sync_map_state (struct multipath *);
+void sync_map_state (struct multipath *mpp, bool reinstate_only);
 struct multipath * add_map_with_path (struct vectors * vecs,
 				      struct path * pp, int add_vec,
 				      const struct multipath *current_mpp);
 void update_queue_mode_del_path(struct multipath *mpp);
 void update_queue_mode_add_path(struct multipath *mpp);
+int update_multipath_table__ (struct multipath *mpp, vector pathvec, int flags,
+			      const char *params, const char *status);
 int update_multipath_table (struct multipath *mpp, vector pathvec, int flags);
 int update_multipath_status (struct multipath *mpp);
-vector get_used_hwes(const struct _vector *pathvec);
+vector get_used_hwes(const struct vector_s *pathvec);
 
-#endif /* _STRUCTS_VEC_H */
+#endif /* STRUCTS_VEC_H_INCLUDED */
