@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: GPL-2.0-only
 /*
  * uevent.c - trigger upon netlink uevents from the kernel
  *
@@ -7,19 +8,6 @@
  *	  gcc -I /lib/modules/`uname -r`/build/include -o uevent_listen uevent_listen.c
  *
  * Copyright (C) 2004 Kay Sievers <kay.sievers@vrfy.org>
- *
- *	This program is free software; you can redistribute it and/or modify it
- *	under the terms of the GNU General Public License as published by the
- *	Free Software Foundation version 2 of the License.
- *
- *	This program is distributed in the hope that it will be useful, but
- *	WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *	General Public License for more details.
- *
- *	You should have received a copy of the GNU General Public License along
- *	with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
  */
 
 #include <unistd.h>
