@@ -30,8 +30,13 @@ static int process_req(int fd, char * inbuf, unsigned int timeout)
 			printf("error %d receiving packet\n", ret);
 		return 1;
 	} else {
-		printf("%s", reply);
-		ret = (strcmp(reply, "fail\n") == 0);
+		ret = (strncmp(reply, "fail\n", 5) == 0);
+		/* If there is additional failure information, skip the
+		 * initial 'fail' */
+		if (ret && strlen(reply) > 5)
+			printf("%s", reply + 5);
+		else
+			printf("%s", reply);
 		free(reply);
 		return ret;
 	}
@@ -47,8 +52,10 @@ int uxclnt(char * inbuf, unsigned int timeout)
 	if (!inbuf)
 		return 1;
 	fd = mpath_connect();
-	if (fd == -1)
+	if (fd == -1) {
+		fprintf(stderr, "ERROR: failed to connect to multipathd\n");
 		return 1;
+	}
 
 	ret = process_req(fd, inbuf, timeout);
 
