@@ -25,7 +25,7 @@
 #define MPATH_ID_INT_MAX_p1 "fxshrxx"
 #endif
 
-static int __set_errno(int err)
+static int set_errno__(int err)
 {
 	if (err >= 0) {
 		errno = 0;
@@ -63,12 +63,12 @@ ssize_t __wrap_write(int fd, const void *buf, size_t count)
 	start = strstr(start, binding);
 	check_expected(count);
 	assert_ptr_not_equal(start, NULL);
-	return __set_errno(mock_type(int));
+	return set_errno__(mock_type(int));
 }
 
 int __wrap_rename(const char *old, const char *new)
 {
-	return __set_errno(mock_type(int));
+	return set_errno__(mock_type(int));
 }
 
 int WRAP_FUNC(mkstemp)(char *template)
@@ -76,7 +76,7 @@ int WRAP_FUNC(mkstemp)(char *template)
 	return 10;
 }
 
-int __wrap_dm_get_uuid(const char *name, char *uuid, int uuid_len)
+int __wrap_dm_get_wwid(const char *name, char *uuid, int uuid_len)
 {
 	int ret;
 
@@ -84,7 +84,7 @@ int __wrap_dm_get_uuid(const char *name, char *uuid, int uuid_len)
 	check_expected(uuid_len);
 	assert_non_null(uuid);
 	ret = mock_type(int);
-	if (ret == 0)
+	if (ret == DMP_OK)
 		strcpy(uuid, mock_ptr_type(char *));
 	return ret;
 }
@@ -134,7 +134,7 @@ int __wrap_pthread_mutex_unlock(pthread_mutex_t *mutex)
 #define TEST_FPTR ((FILE *) 0xaffe)
 
 /* strbuf wrapper for the old format_devname() */
-static int __format_devname(char *name, int id, size_t len, const char *prefix)
+static int format_devname__(char *name, int id, size_t len, const char *prefix)
 {
 	STRBUF_ON_STACK(buf);
 
@@ -151,7 +151,7 @@ static void fd_mpatha(void **state)
 	char buf[32];
 	int rc;
 
-	rc = __format_devname(buf, 1, sizeof(buf), "FOO");
+	rc = format_devname__(buf, 1, sizeof(buf), "FOO");
 	assert_int_equal(rc, 4);
 	assert_string_equal(buf, "FOOa");
 }
@@ -162,7 +162,7 @@ static void fd_mpathz(void **state)
 	char buf[5];
 	int rc;
 
-	rc = __format_devname(buf, 26, sizeof(buf), "FOO");
+	rc = format_devname__(buf, 26, sizeof(buf), "FOO");
 	assert_int_equal(rc, 4);
 	assert_string_equal(buf, "FOOz");
 }
@@ -172,7 +172,7 @@ static void fd_mpathaa(void **state)
 	char buf[32];
 	int rc;
 
-	rc = __format_devname(buf, 26 + 1, sizeof(buf), "FOO");
+	rc = format_devname__(buf, 26 + 1, sizeof(buf), "FOO");
 	assert_int_equal(rc, 5);
 	assert_string_equal(buf, "FOOaa");
 }
@@ -182,7 +182,7 @@ static void fd_mpathzz(void **state)
 	char buf[32];
 	int rc;
 
-	rc = __format_devname(buf, 26*26 + 26, sizeof(buf), "FOO");
+	rc = format_devname__(buf, 26*26 + 26, sizeof(buf), "FOO");
 	assert_int_equal(rc, 5);
 	assert_string_equal(buf, "FOOzz");
 }
@@ -192,7 +192,7 @@ static void fd_mpathaaa(void **state)
 	char buf[32];
 	int rc;
 
-	rc = __format_devname(buf, 26*26 + 27, sizeof(buf), "FOO");
+	rc = format_devname__(buf, 26*26 + 27, sizeof(buf), "FOO");
 	assert_int_equal(rc, 6);
 	assert_string_equal(buf, "FOOaaa");
 }
@@ -202,7 +202,7 @@ static void fd_mpathzzz(void **state)
 	char buf[32];
 	int rc;
 
-	rc = __format_devname(buf, 26*26*26 + 26*26 + 26, sizeof(buf), "FOO");
+	rc = format_devname__(buf, 26*26*26 + 26*26 + 26, sizeof(buf), "FOO");
 	assert_int_equal(rc, 6);
 	assert_string_equal(buf, "FOOzzz");
 }
@@ -212,7 +212,7 @@ static void fd_mpathaaaa(void **state)
 	char buf[32];
 	int rc;
 
-	rc = __format_devname(buf, 26*26*26 + 26*26 + 27, sizeof(buf), "FOO");
+	rc = format_devname__(buf, 26*26*26 + 26*26 + 27, sizeof(buf), "FOO");
 	assert_int_equal(rc, 7);
 	assert_string_equal(buf, "FOOaaaa");
 }
@@ -222,7 +222,7 @@ static void fd_mpathzzzz(void **state)
 	char buf[32];
 	int rc;
 
-	rc = __format_devname(buf, 26*26*26*26 + 26*26*26 + 26*26 + 26,
+	rc = format_devname__(buf, 26*26*26*26 + 26*26*26 + 26*26 + 26,
 			    sizeof(buf), "FOO");
 	assert_int_equal(rc, 7);
 	assert_string_equal(buf, "FOOzzzz");
@@ -234,7 +234,7 @@ static void fd_mpath_max(void **state)
 	char buf[32];
 	int rc;
 
-	rc  = __format_devname(buf, INT_MAX, sizeof(buf), "");
+	rc  = format_devname__(buf, INT_MAX, sizeof(buf), "");
 	assert_int_equal(rc, strlen(MPATH_ID_INT_MAX));
 	assert_string_equal(buf, MPATH_ID_INT_MAX);
 }
@@ -245,7 +245,7 @@ static void fd_mpath_max1(void **state)
 	char buf[32];
 	int rc;
 
-	rc  = __format_devname(buf, INT_MIN, sizeof(buf), "");
+	rc  = format_devname__(buf, INT_MIN, sizeof(buf), "");
 	assert_int_equal(rc, -1);
 }
 
@@ -254,7 +254,7 @@ static void fd_mpath_short(void **state)
 	char buf[4];
 	int rc;
 
-	rc = __format_devname(buf, 1, sizeof(buf), "FOO");
+	rc = format_devname__(buf, 1, sizeof(buf), "FOO");
 	assert_int_equal(rc, -1);
 }
 
@@ -263,7 +263,7 @@ static void fd_mpath_short1(void **state)
 	char buf[5];
 	int rc;
 
-	rc = __format_devname(buf, 27, sizeof(buf), "FOO");
+	rc = format_devname__(buf, 27, sizeof(buf), "FOO");
 	assert_int_equal(rc, -1);
 }
 
@@ -388,7 +388,7 @@ static void sd_fd_many(void **state)
 	int rc, i;
 
 	for (i = 1; i < 5000; i++) {
-		rc = __format_devname(buf, i, sizeof(buf), "MPATH");
+		rc = format_devname__(buf, i, sizeof(buf), "MPATH");
 		assert_in_range(rc, 6, 8);
 		rc = scan_devname(buf, "MPATH");
 		assert_int_equal(rc, i);
@@ -403,7 +403,7 @@ static void sd_fd_random(void **state)
 	srandom(1);
 	for (i = 1; i < 1000; i++) {
 		n = random() & 0xffff;
-		rc = __format_devname(buf, n, sizeof(buf), "MPATH");
+		rc = format_devname__(buf, n, sizeof(buf), "MPATH");
 		assert_in_range(rc, 6, 9);
 		rc = scan_devname(buf, "MPATH");
 		assert_int_equal(rc, n);
@@ -436,17 +436,17 @@ static int test_scan_devname(void)
 
 static void mock_unused_alias(const char *alias)
 {
-	expect_string(__wrap_dm_get_uuid, name, alias);
-	expect_value(__wrap_dm_get_uuid, uuid_len, WWID_SIZE);
-	will_return(__wrap_dm_get_uuid, 1);
+	expect_string(__wrap_dm_get_wwid, name, alias);
+	expect_value(__wrap_dm_get_wwid, uuid_len, WWID_SIZE);
+	will_return(__wrap_dm_get_wwid, DMP_NOT_FOUND);
 }
 
 static void mock_self_alias(const char *alias, const char *wwid)
 {
-	expect_string(__wrap_dm_get_uuid, name, alias);
-	expect_value(__wrap_dm_get_uuid, uuid_len, WWID_SIZE);
-	will_return(__wrap_dm_get_uuid, 0);
-	will_return(__wrap_dm_get_uuid, wwid);
+	expect_string(__wrap_dm_get_wwid, name, alias);
+	expect_value(__wrap_dm_get_wwid, uuid_len, WWID_SIZE);
+	will_return(__wrap_dm_get_wwid, DMP_OK);
+	will_return(__wrap_dm_get_wwid, wwid);
 }
 
 #define USED_STR(alias_str, wwid_str) wwid_str ": alias '" alias_str "' already taken, reselecting alias\n"
@@ -469,21 +469,21 @@ static void mock_self_alias(const char *alias, const char *wwid)
 
 #define mock_failed_alias(alias, wwid)					\
 	do {								\
-		expect_string(__wrap_dm_get_uuid, name, alias);		\
-		expect_value(__wrap_dm_get_uuid, uuid_len, WWID_SIZE);	\
-		will_return(__wrap_dm_get_uuid, 1);			\
+		expect_string(__wrap_dm_get_wwid, name, alias);		\
+		expect_value(__wrap_dm_get_wwid, uuid_len, WWID_SIZE);	\
+		will_return(__wrap_dm_get_wwid, DMP_NOT_FOUND);		\
 	} while (0)
 
 #define mock_used_alias(alias, wwid)					\
 	do {								\
-		expect_string(__wrap_dm_get_uuid, name, alias);		\
-		expect_value(__wrap_dm_get_uuid, uuid_len, WWID_SIZE);	\
-		will_return(__wrap_dm_get_uuid, 0);			\
-		will_return(__wrap_dm_get_uuid, "WWID_USED");		\
+		expect_string(__wrap_dm_get_wwid, name, alias);		\
+		expect_value(__wrap_dm_get_wwid, uuid_len, WWID_SIZE);	\
+		will_return(__wrap_dm_get_wwid, DMP_OK);		\
+		will_return(__wrap_dm_get_wwid, "WWID_USED");		\
 		expect_condlog(3, USED_STR(alias, wwid));		\
 	} while(0)
 
-static void __mock_bindings_file(const char *content, bool conflict_ok)
+static void mock_bindings_file__(const char *content, bool conflict_ok)
 {
 	char *cnt __attribute__((cleanup(cleanup_charp))) = NULL;
 	char *token, *savep = NULL;
@@ -509,7 +509,7 @@ static void __mock_bindings_file(const char *content, bool conflict_ok)
 }
 
 static void mock_bindings_file(const char *content) {
-	return __mock_bindings_file(content, false);
+	return mock_bindings_file__(content, false);
 }
 
 static int teardown_bindings(void **state)
@@ -1438,6 +1438,7 @@ static void gufa_empty_new_rw(void **state) {
 
 	mock_bindings_file("");
 	mock_unused_alias("MPATHa");
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, NOMATCH_WWID_STR("WWID0"));
 
 	mock_allocate_binding("MPATHa", "WWID0");
@@ -1451,6 +1452,7 @@ static void gufa_empty_new_ro_1(void **state) {
 
 	mock_bindings_file("");
 	mock_unused_alias("MPATHa");
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, NOMATCH_WWID_STR("WWID0"));
 	mock_allocate_binding_err("MPATHa", "WWID0", -EROFS, "Read-only file system");
 
@@ -1462,6 +1464,7 @@ static void gufa_empty_new_ro_2(void **state) {
 	char *alias;
 
 	mock_bindings_file("");
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, NOMATCH_WWID_STR("WWID0"));
 	mock_unused_alias("MPATHa");
 
@@ -1473,6 +1476,7 @@ static void gufa_match_a_unused(void **state) {
 	char *alias;
 
 	mock_bindings_file("MPATHa WWID0");
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, FOUND_STR("MPATHa", "WWID0"));
 	mock_unused_alias("MPATHa");
 	expect_condlog(3, EXISTING_STR("MPATHa", "WWID0"));
@@ -1486,6 +1490,7 @@ static void gufa_match_a_self(void **state) {
 	char *alias;
 
 	mock_bindings_file("MPATHa WWID0");
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, FOUND_STR("MPATHa", "WWID0"));
 	mock_self_alias("MPATHa", "WWID0");
 	expect_condlog(3, EXISTING_STR("MPATHa", "WWID0"));
@@ -1500,6 +1505,7 @@ static void gufa_match_a_used(void **state) {
 
 
 	mock_bindings_file("MPATHa WWID0");
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, FOUND_STR("MPATHa", "WWID0"));
 	mock_used_alias("MPATHa", "WWID0");
 
@@ -1514,6 +1520,7 @@ static void gufa_nomatch_a_c(void **state) {
 
 	mock_bindings_file(bindings);
 	mock_unused_alias("MPATHb");
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, NOMATCH_WWID_STR("WWID1"));
 
 	mock_allocate_binding_len("MPATHb", "WWID1", strlen(bindings));
@@ -1530,6 +1537,7 @@ static void gufa_nomatch_c_a(void **state) {
 
 	mock_bindings_file(bindings);
 	mock_unused_alias("MPATHb");
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, NOMATCH_WWID_STR("WWID1"));
 
 	mock_allocate_binding_len("MPATHb", "WWID1", sizeof(bindings) - 1);
@@ -1545,6 +1553,7 @@ static void gufa_nomatch_c_b(void **state) {
 				 "MPATHb WWID1\n");
 
 	mock_bindings_file(bindings);
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, NOMATCH_WWID_STR("WWID0"));
 	mock_unused_alias("MPATHa");
 
@@ -1561,6 +1570,7 @@ static void gufa_nomatch_c_b_used(void **state) {
 				 "MPATHb WWID1\n");
 
 	mock_bindings_file(bindings);
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, NOMATCH_WWID_STR("WWID4"));
 	mock_used_alias("MPATHa", "WWID4");
 	mock_unused_alias("MPATHd");
@@ -1579,6 +1589,7 @@ static void gufa_nomatch_b_f_a(void **state) {
 				 "MPATHa WWID0\n");
 
 	mock_bindings_file(bindings);
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, NOMATCH_WWID_STR("WWID7"));
 	mock_unused_alias("MPATHc");
 
@@ -1595,6 +1606,7 @@ static void gufa_nomatch_b_aa_a(void **state) {
 
 	fill_bindings(&buf, 0, 26);
 	mock_bindings_file(get_strbuf_str(&buf));
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, NOMATCH_WWID_STR("WWID28"));
 	mock_unused_alias("MPATHab");
 	mock_allocate_binding_len("MPATHab", "WWID28", get_strbuf_len(&buf));
@@ -1611,6 +1623,7 @@ static void gufa_nomatch_b_f_a_sorted(void **state) {
 				 "MPATHa WWID0\n");
 
 	mock_bindings_file(bindings);
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, NOMATCH_WWID_STR("WWID7"));
 	mock_unused_alias("MPATHc");
 
@@ -1626,6 +1639,7 @@ static void gufa_old_empty(void **state) {
 
 	/* rlookup_binding for ALIAS */
 	mock_bindings_file("");
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, NOMATCH_STR("MPATHz"));
 	expect_condlog(3, NOMATCH_WWID_STR("WWID0"));
 
@@ -1642,6 +1656,7 @@ static void gufa_old_match(void **state) {
 
 	mock_bindings_file("MPATHb WWID1\n"
 			   "MPATHz WWID0");
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, FOUND_ALIAS_STR("MPATHz", "WWID0"));
 
 	alias = get_user_friendly_alias("WWID0", "MPATHz", "MPATH", false);
@@ -1654,6 +1669,7 @@ static void gufa_old_match_other(void **state) {
 	static const char bindings[] = "MPATHz WWID9\n";
 
 	mock_bindings_file(bindings);
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, FOUND_ALIAS_STR("MPATHz", "WWID9"));
 	expect_condlog(0, REUSE_STR("MPATHz", "WWID9"));
 	expect_condlog(3, NOMATCH_WWID_STR("WWID0"));
@@ -1671,6 +1687,7 @@ static void gufa_old_match_other_used(void **state) {
 	static const char bindings[] = "MPATHz WWID9\n";
 
 	mock_bindings_file(bindings);
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, FOUND_ALIAS_STR("MPATHz", "WWID9"));
 	expect_condlog(0, REUSE_STR("MPATHz", "WWID9"));
 	expect_condlog(3, NOMATCH_WWID_STR("WWID0"));
@@ -1689,6 +1706,7 @@ static void gufa_old_match_other_wwidmatch(void **state) {
 					"MPATHc WWID2");
 
 	mock_bindings_file(bindings);
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, FOUND_ALIAS_STR("MPATHz", "WWID9"));
 	expect_condlog(0, REUSE_STR("MPATHz", "WWID9"));
 	expect_condlog(3, FOUND_STR("MPATHc", "WWID2"));
@@ -1706,6 +1724,7 @@ static void gufa_old_match_other_wwidmatch_used(void **state) {
 					"MPATHc WWID2");
 
 	mock_bindings_file(bindings);
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, FOUND_ALIAS_STR("MPATHz", "WWID9"));
 	expect_condlog(0, REUSE_STR("MPATHz", "WWID9"));
 	expect_condlog(3, FOUND_STR("MPATHc", "WWID2"));
@@ -1720,6 +1739,7 @@ static void gufa_old_nomatch_wwidmatch(void **state) {
 	static const char bindings[] = "MPATHa WWID0";
 
 	mock_bindings_file(bindings);
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, NOMATCH_STR("MPATHz"));
 	expect_condlog(3, FOUND_STR("MPATHa", "WWID0"));
 	mock_unused_alias("MPATHa");
@@ -1735,6 +1755,7 @@ static void gufa_old_nomatch_wwidmatch_used(void **state) {
 	static const char bindings[] = "MPATHa WWID0";
 
 	mock_bindings_file(bindings);
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, NOMATCH_STR("MPATHz"));
 	expect_condlog(3, FOUND_STR("MPATHa", "WWID0"));
 	mock_used_alias("MPATHa", "WWID0");
@@ -1748,6 +1769,7 @@ static void gufa_old_nomatch_nowwidmatch(void **state) {
 	static const char bindings[] = "MPATHb WWID1\n";
 
 	mock_bindings_file(bindings);
+	expect_condlog(4, "_read_bindings_file: bindings are unchanged");
 	expect_condlog(3, NOMATCH_STR("MPATHz"));
 	expect_condlog(3, NOMATCH_WWID_STR("WWID0"));
 
@@ -1896,7 +1918,7 @@ static void order_test(int n, const struct random_aliases ra[], bool conflict_ok
 
 	for (j = 0; j < n; j++)
 		fill_bindings_random(&buf, ra[j].start, ra[j].end, ra[j].prefix);
-	__mock_bindings_file(get_strbuf_str(&buf), conflict_ok);
+	mock_bindings_file__(get_strbuf_str(&buf), conflict_ok);
 
 	for (j = 0; j < n; j++) {
 		bdg = VECTOR_SLOT(bindings, 0);
